Grapycal

# About

Grapycal is an open source project [Github]. Welcome to join and contribute!
Grapycal is designed with the goal to align with human perception at best, while being powerful with the help of Python, its backend.
If you're new, you may be unfamiliar with the syntax, but you'll soon find it easy to use! These may help you get started:

- docs.grapycal.org
- 📁 Files > 💡Example workspaces

# Files

# Node List

Want more nodes? Extend the list at 🚀Extensions tab.

# Extensions

## In Use

## Avaliable

## Not Installed

# Settings